<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>AppMain</name>
    <message>
        <location filename="../src/common/vlcplayer.cpp" line="87"/>
        <source>Voice Notes</source>
        <translation>Голосові нотатки</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
        <source>Notebook</source>
        <translation>Нотатник</translation>
    </message>
    <message>
        <location filename="../src/importolddata/olddbvisistors.cpp" line="139"/>
        <source>Voice</source>
        <translation>Голосова</translation>
    </message>
    <message>
        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FolderListView</name>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="517"/>
        <source>Rename</source>
        <translation type="unfinished">Перейменувати</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="526"/>
        <source>Delete</source>
        <translation type="unfinished">Вилучити</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
        <source>New Note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InitialInterface</name>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
        <source>After creating a new notepad, you can start recording voice and text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Створити теку</translation>
    </message>
</context>
<context>
    <name>ItemListView</name>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
        <source>move </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source> notes to :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
        <source> note to :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="222"/>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
        <source>No search results</source>
        <translation type="unfinished">Немає результатів</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Unpin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Sticky on Top</source>
        <translation type="unfinished">Приліпити згори</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
        <source>Sticky Notes</source>
        <translation type="unfinished">Липкі нотатки</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Створити теку</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
        <source>Search</source>
        <translation type="unfinished">Пошук</translation>
    </message>
</context>
<context>
    <name>MoveDialog</name>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
        <source>Move Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
        <source>Cancel</source>
        <translation type="unfinished">Скасувати</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultipleChoices</name>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
        <source>%1 note selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
        <source>Move</source>
        <translation type="unfinished">Пересунути</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
        <source>Save Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
        <source>Save Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
        <source>Delete</source>
        <translation type="unfinished">Вилучити</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="69"/>
        <source>Save as MP3</source>
        <translation>Зберегти як MP3</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="70"/>
        <source>Voice to Text</source>
        <translation>Перетворити на текст</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="71"/>
        <location filename="../src/common/actionmanager.cpp" line="79"/>
        <location filename="../src/common/actionmanager.cpp" line="87"/>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="72"/>
        <location filename="../src/common/actionmanager.cpp" line="80"/>
        <location filename="../src/common/actionmanager.cpp" line="88"/>
        <source>Select all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="73"/>
        <location filename="../src/common/actionmanager.cpp" line="81"/>
        <location filename="../src/common/actionmanager.cpp" line="89"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="74"/>
        <location filename="../src/common/actionmanager.cpp" line="82"/>
        <location filename="../src/common/actionmanager.cpp" line="90"/>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="75"/>
        <location filename="../src/common/actionmanager.cpp" line="83"/>
        <location filename="../src/common/actionmanager.cpp" line="91"/>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="78"/>
        <source>View</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="84"/>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="93"/>
        <source>Text to Speech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="94"/>
        <source>Stop reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="95"/>
        <source>Speech to Text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="47"/>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="48"/>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="49"/>
        <source>New note</source>
        <translation type="unfinished">Нова нотатка</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="63"/>
        <source>Save as HTML</source>
        <translation>Зберегти як HTML</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="64"/>
        <source>Save as TXT</source>
        <translation>Зберегти як TXT</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="57"/>
        <source>Save note</source>
        <translation>Зберегти нотатку</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="52"/>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="54"/>
        <source>Move</source>
        <translation>Пересунути</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="55"/>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="58"/>
        <source>Save voice recording</source>
        <translation>Зберегти запис голосу</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="60"/>
        <source>New note</source>
        <translation>Нова нотатка</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="53"/>
        <source>Sticky on Top</source>
        <translation>Приліпити згори</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
        <source>Please install &apos;UOS AI&apos; from the App Store before using</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
        <source>No audio input device detected. Please check and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
        <source>No audio output device detected. Please check and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>deepin-voice-note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="../src/common/setting.cpp" line="24"/>
        <source>Basic</source>
        <translation>Основа</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="25"/>
        <source>Audio Source</source>
        <translation>Джерело звуку</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="26"/>
        <source>Internal</source>
        <translation>Вбудоване</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="27"/>
        <source>Microphone</source>
        <translation>Мікрофон</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="27"/>
        <source>Basic</source>
        <translation type="unfinished">Основа</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="32"/>
        <source>Audio Source</source>
        <translation type="unfinished">Джерело звуку</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="59"/>
        <source>Internal</source>
        <translation type="unfinished">Вбудоване</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="68"/>
        <source>Microphone</source>
        <translation type="unfinished">Мікрофон</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
        <source>New notebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
        <source>Rename notebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
        <source>Delete notebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
        <source>New note</source>
        <translation type="unfinished">Нова нотатка</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
        <source>Rename note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
        <source>Delete note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
        <source>Play/Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
        <source>Record voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
        <source>Save note</source>
        <translation type="unfinished">Зберегти нотатку</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
        <source>Save recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
        <source>Select all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
        <source>Copy</source>
        <translation type="unfinished">Копіювати</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
        <source>Cut</source>
        <translation type="unfinished">Вирізати</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
        <source>Paste</source>
        <translation type="unfinished">Вставити</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
        <source>Delete</source>
        <translation type="unfinished">Вилучити</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
        <source>Notebooks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
        <source>Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
        <source>Settings</source>
        <translation type="unfinished">Параметри</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="16"/>
        <source>Settings</source>
        <translation type="unfinished">Параметри</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
        <source>Privacy Policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
        <source>Voice Note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="../src/importolddata/upgradeview.cpp" line="35"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>Імпортуємо нотатки зі старої версії. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="46"/>
        <location filename="../tests/src/common/ut_utils.cpp" line="32"/>
        <source>1 min ago</source>
        <translation>1 хв. тому</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="48"/>
        <source>%1 mins ago</source>
        <translation>%1 хв. тому</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="56"/>
        <location filename="../tests/src/common/ut_utils.cpp" line="37"/>
        <source>Yesterday</source>
        <translation>Вчора</translation>
    </message>
    <message>
        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
        <source>2 mins ago</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Виконуємо записування. Хочете його перервати?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Не вдалося перетворити цю голосову нотатку на текстову. У поточній версії не передбачено підтримки файлів із тривалістю відтворення звукових даних понад 20 хвилин.</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">Виконуємо перетворення голосової нотатки. Хочете зупинити цю дію?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Низький рівень вхідного сигналу може призвести до неякісного запису. Хочете продовжувати попри це?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">Обрізані записи та перетворений текст не буде вставлено. Хочете продовжити?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Ви справді хочете вилучити цю нотатку?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Ви справді хочете вилучити позначені %1 нотаток?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Скасувати</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished">Підтвердження</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
        <source>Save failed</source>
        <translation type="unfinished">Не вдалося зберегти</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">У вас немає прав доступу для зберігання файлів у вказаному місці</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">Голосове нагадування вилучено</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogHandler</name>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
        <source>Are you sure you want to delete this notebook?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Виконуємо записування. Хочете його перервати?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="103"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Ви справді хочете вилучити позначені %1 нотаток?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="107"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Ви справді хочете вилучити цю нотатку?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="110"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Не вдалося перетворити цю голосову нотатку на текстову. У поточній версії не передбачено підтримки файлів із тривалістю відтворення звукових даних понад 20 хвилин.</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="114"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">Виконуємо перетворення голосової нотатки. Хочете зупинити цю дію?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="116"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Низький рівень вхідного сигналу може призвести до неякісного запису. Хочете продовжувати попри це?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="119"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">Обрізані записи та перетворений текст не буде вставлено. Хочете продовжити?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="123"/>
        <source>Save failed</source>
        <translation type="unfinished">Не вдалося зберегти</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="125"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">У вас немає прав доступу для зберігання файлів у вказаному місці</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="127"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">Голосове нагадування вилучено</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
        <source>All notes in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
        <source>Delete</source>
        <translation type="unfinished">Вилучити</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogLoader</name>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="150"/>
        <source>Cancel</source>
        <translation type="unfinished">Скасувати</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="183"/>
        <source>Confirm</source>
        <translation type="unfinished">Підтвердження</translation>
    </message>
</context>
<context>
    <name>WebEngineHandler</name>
    <message>
        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
        <source>save as MP3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowTitleBar</name>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
        <source>Create Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>Start recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>No recording device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
        <source>Insert picture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="../src/common/jscontent.cpp" line="146"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="147"/>
        <source>Font size</source>
        <translation>Розмір шрифту</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="148"/>
        <source>Font color</source>
        <translation>Колір шрифту</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="149"/>
        <source>Text highlight color</source>
        <translation>Колір підсвічування тексту</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="150"/>
        <source>Bold</source>
        <translation>Жирний</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="151"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="152"/>
        <source>Underline</source>
        <translation>Підкреслювання</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="153"/>
        <source>Strikethrough</source>
        <translation>Перекреслювання</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="154"/>
        <source>Bullets</source>
        <translation>Пункти</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="155"/>
        <source>Numbering</source>
        <translation>Нумерація</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="156"/>
        <source>More colors</source>
        <translation>Більше кольорів</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="157"/>
        <source>Recent</source>
        <translation>Нещодавні</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="173"/>
        <source>Voice To Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="174"/>
        <source>Converting voice to text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
